(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[405],{8312:function(e,t,n){(window.__NEXT_P=window.__NEXT_P||[]).push(["/",function(){return n(4186)}])},6771:function(e,t,n){"use strict";n.d(t,{Z:function(){return w}});var r=n(5893),i=n(7294),o=n(1163),s=n(9008),a=n.n(s),c=n(8298),l=n(2734),d=n(2293),u=n(9520),p=n(155),m=n(6886),f=n(3321),h=n(5861),y=n(7357);function x(e){var t=e.children,n=(0,c.Z)({disableHysteresis:!0,threshold:24});return(0,i.cloneElement)(t,{elevation:n?4:0})}var v=function(){var e=(0,i.useState)(!1),t=e[0],n=e[1],o=((0,i.useCallback)((function(){n(!t)}),[t]),(0,l.Z)());return(0,r.jsx)(r.Fragment,{children:(0,r.jsx)(x,{children:(0,r.jsxs)(r.Fragment,{children:[(0,r.jsx)(d.Z,{color:"transparent",elevation:0,children:(0,r.jsx)(u.Z,{maxWidth:"xl",sx:{padding:0},children:(0,r.jsx)(p.Z,{sx:{minHeight:50,maxHeight:50,padding:0,flex:1,alignItems:"center",justifyContent:"space-between",display:"flex",flexWrap:"nowrap"},children:(0,r.jsx)(m.ZP,{item:!0,children:(0,r.jsx)(f.Z,{href:"https://system-bridge.timmo.dev",target:"_blank",children:(0,r.jsx)(h.Z,{component:"div",variant:"h4",sx:{textTransform:"none",userSelect:"none",color:o.palette.primary.contrastText},children:"System Bridge"})})})})})}),(0,r.jsx)(y.Z,{sx:{height:o.spacing(18)}})]})})})};function g(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function j(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{},r=Object.keys(n);"function"===typeof Object.getOwnPropertySymbols&&(r=r.concat(Object.getOwnPropertySymbols(n).filter((function(e){return Object.getOwnPropertyDescriptor(n,e).enumerable})))),r.forEach((function(t){g(e,t,n[t])}))}return e}var b=!1;var w=function(e){var t=(0,o.useRouter)();return(0,i.useEffect)((function(){if(t.isReady&&!b){var e,n,r,i;b=!0;var o=(null===(e=t.query)||void 0===e?void 0:e.apiKey)||"",s=(null===(n=t.query)||void 0===n?void 0:n.apiPort)||"9170",a=!1;if((null===(r=t.query)||void 0===r?void 0:r.apiKey)||(a=!0,o=window.prompt("Please enter your API key",o)),(null===(i=t.query)||void 0===i?void 0:i.apiPort)||(a=!0,s=window.prompt("Please enter your API port (default: 9170)",s)),a&&o&&s){var c=t.asPath.split("?")[0];t.replace({pathname:c.includes(".html")?c:"".concat(c,".html"),query:j({},t.query,{apiKey:o,apiPort:s})})}}}),[t]),(0,r.jsxs)(r.Fragment,{children:[(0,r.jsxs)(a(),{children:[(0,r.jsx)("title",{children:e.title?"".concat(e.title," - System Bridge"):"System Bridge"}),(0,r.jsx)("link",{rel:"canonical",href:e.url}),(0,r.jsx)("meta",{name:"description",content:e.description?"".concat(e.description):e.title?"".concat(e.title," - System Bridge"):"System Bridge"}),(0,r.jsx)("meta",{name:"keywords",content:e.keywords?"".concat(e.keywords):"system-bridge, system, bridge, typescript"})]}),!e.noHeader&&(0,r.jsx)(v,{}),e.children]})}},4186:function(e,t,n){"use strict";n.r(t);var r=n(5893),i=(n(7294),n(9520)),o=n(6771);t.default=function(){return(0,r.jsx)(o.Z,{title:"Placeholder",url:"https://system-bridge.timmo.dev",description:"Frontend for System Bridge",children:(0,r.jsx)(i.Z,{component:"article",maxWidth:"xl",children:(0,r.jsx)(r.Fragment,{})})})}}},function(e){e.O(0,[538,774,888,179],(function(){return t=8312,e(e.s=t);var t}));var t=e.O();_N_E=t}]);