self.__BUILD_MANIFEST=function(s,c,a,e,t,p){return{__rewrites:{beforeFiles:[],afterFiles:[],fallback:[]},"/":[s,"static/chunks/pages/index-4a4864f1b3377f3b.js"],"/_error":["static/chunks/pages/_error-0a004b8b8498208d.js"],"/app/bridges/openon":[s,c,a,e,t,"static/chunks/pages/app/bridges/openon-adf681e53c563a61.js"],"/app/bridges/setup":[s,c,a,t,p,"static/chunks/50-bd09e5441b6a0cc9.js","static/chunks/pages/app/bridges/setup-90859f5b5543313e.js"],"/app/data":["static/chunks/29107295-fbcfe2172188e46f.js",s,c,"static/chunks/398-131474884e7d585c.js","static/chunks/pages/app/data-9524b07ef08665c5.js"],"/app/settings":["static/chunks/b2e984c5-693913ad9f176f98.js",s,c,a,e,p,"static/chunks/244-93fadd0d74a248a8.js","static/chunks/pages/app/settings-96bb3b8803ee16dd.js"],sortedPages:["/","/_app","/_error","/app/bridges/openon","/app/bridges/setup","/app/data","/app/settings"]}}("static/chunks/538-3b65ee0815096060.js","static/chunks/316-038ef62e121c95f8.js","static/chunks/699-31e460ef5e5a389a.js","static/chunks/713-0cc2f171f69f91a6.js","static/chunks/669-b40c0839a3190627.js","static/chunks/257-7cf6021de27e18db.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();